#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['pymultirole_plugins', 'pymultirole_plugins.v1']

package_data = \
{'': ['*']}

install_requires = \
['pydantic==1.10.8',
 'fastapi==0.61.2',
 'python-singleton-metaclasses',
 'pytest']

extras_require = \
{'docs': ['sphinx',
          'sphinx-rtd-theme',
          'm2r2',
          'sphinxcontrib.apidoc',
          'jupyter_sphinx'],
 'test': ['pytest',
          'pytest-cov',
          'pytest-flake8',
          'pytest-black',
          'flake8==3.9.2',
          'tox',
          'dirty-equals']}

setup(name='pymultirole-plugins',
      version='0.5.678',
      description='Sherpa multirole plugins',
      author='Olivier Terrier',
      author_email='olivier.terrier@kairntech.com',
      url='https://kairntech.com/',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.8',
     )
